@@ -1,3 +1,6 @@
+from pkgutil import extend_path
+__path__ = extend_path(__path__, __name__)
+
 import abc
 import builtins
 import datetime
@@ -15,9 +18,9 @@ import constructs._jsii
 
 __jsii_assembly__ = jsii.JSIIAssembly.load(
     "@dontirun/state-machine-semaphore",
-    "0.1.460",
+    "0.1.558",
     __name__[0:-6],
-    "state-machine-semaphore@0.1.460.jsii.tgz",
+    "state-machine-semaphore@0.1.558.jsii.tgz",
 )
 
 __all__ = [
